# -*- coding: utf-8 -*-
import re, json, time
try:
    from urllib2 import urlopen, Request
except ImportError:
    from urllib.request import urlopen, Request
try:
    from urlparse import urlparse, urljoin
except ImportError:
    from urllib.parse import urlparse, urljoin
try:
    from urllib import quote, urlencode
except ImportError:
    from urllib.parse import quote, urlencode
ua = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.88 Safari/537.36'


def httpget(url, data=None):
    request = Request(url, data=data, headers={'User-Agent': ua})
    return urlopen(request).read().decode('utf-8')


def getjson(url, data=None):
    request = Request(url, data=data, headers={'User-Agent': ua})
    return json.load(urlopen(request))


def sports():
    # post data to http://www.huaren.tv/
    # data = {
    #     'timeOffset': 39600,
    #     'timestamp_start': 1608901200,
    #     'formatTimestampEndStart': '2020-12-26 00:00',
    #     'timestamp_end': 1609506000,
    #     'formatTimestampEnd': '2021-01-02 00:00',
    #     'sportsclass': 0}
    url = 'http://www.huaren.tv/sports'
    try:
        content = httpget(url)
    except Exception as e:
        return {'code': 'huarentv 300', 'error': str(e)}
    content = re.search(r'var\s+pageInfo\s*=\s*(.*?)\s*;', content)
    if not content:
        return {'code': 'huarentv 301'}
    content = content.group(1)
    try:
        data = json.loads(content)
    except Exception as e:
        return {'code': 'huarentv 302', 'error': str(e)}
    try:
        data = data['live_enter']['0']
    except Exception as e:
        return {'code': 'huarentv 303', 'error': str(e)}
    ret = []
    for e in data:
        title = ''
        if 'time' in e:
            title += time.strftime('%d %H:%M', time.localtime(e['time'])) + ' '
        if 'cate' in e:
            title += e['cate']
        if 'team' in e:
            for e1 in e['team']:
                title += ' ' + e1
        if e['url']:
            ret.append({'title': title, 'url': urljoin(url, e['url'])})
    return ret


def tv(id):
    url = 'https://www.huaren.tv/Home/tvstation'
    try:
        data = getjson(url, urlencode({'id': id}))
    except Exception as e:
        return {'code': 'huarentv 300', 'error': str(e)}
    ret = []
    for e in data['data']:
        ret.append({'title': e['title'], 'url': urljoin(url, e['url']), 'img': urljoin(url, e['photo'])})
    return ret


def live(url):
    o = urlparse(url)
    p = o.path.split('/')
    ids = p[-1].split('-')
    try:
        content = httpget(url)
    except Exception as e:
        return {'code': 'huarentv 400', 'error': str(e)}
    if len(ids) <= 1:
        content = re.search(r'window.currentPartInfo\s*=\s*(.*?)\s*;', content)
        if not content:
            return {'code': 'huarentv 401'}
        content = content.group(1)
        try:
            data = json.loads(content)
        except Exception as e:
            return {'code': 'huarentv 402', 'error': str(e)}
        ret = []
        for e1 in data['liveOtherVideo']:
            id1 = e1['tvid']
            for e2 in e1['other_video']:
                id2 = e2['_id']
                ret.append({'title': e2['title'], 'url': '%s-%s' % (url, id2)})
        return ret
    url = re.search(r'changeVideoContent\("m3u8:live","(.*?)"\);', content)
    if not url:
        return {'code': 'huarentv 403'}
    url = url.group(1)
    if url[:2] == '//':
        url = 'http:' + url
    return {'title': '', 'url': url, 'final': True}


def category(cat, page=1):
    if cat == 'movie':
        c = 1
    elif cat == 'tvdrama':
        c = 2
    elif cat == 'show':
        c = 3
    elif cat == 'anime':
        c = 87
    elif cat == 'child':
        c = 101
    elif cat == 'documentary':
        c = 81
    else:
        return {'code': 'huarentv 100'}
    url = 'http://www.wekan.tv/index.php/video?where=%%7B%%22channel%%22%%3A%d%%7D&page=%d&pagesize=30&fields=%%5B%%22_id%%22%%2C%%22title%%22%%2C%%22photo%%22%%2C%%22url%%22%%2C%%22oneword%%22%%2C%%22actor%%22%%2C%%22director%%22%%2C%%22aboutme%%22%%2C%%22score%%22%%2C%%22totalcount%%22%%2C%%22changed%%22%%2C%%22year%%22%%2C%%22msg%%22%%2C%%22tag%%22%%2C%%22tvclass%%22%%2C%%22count%%22%%5D' % (
        c, page)
    try:
        data = getjson(url)
    except Exception as e:
        return {'code': 'huarentv 101', 'error': str(e)}
    ret = []
    if 'data' not in data:
        return {'code': 'huarentv 102'}
    if 'list' not in data['data']:
        return {'code': 'huarentv 103'}
    for e in data['data']['list']:
        plot = []
        if 'score' in e:
            plot.append(str(e['score']))
        if 'msg' in e and e['msg']:
            plot.append(e['msg'])
        if 'year' in e:
            plot.append(str(e['year']))
        if 'tvclass' in e:
            subplot = []
            for e1 in e['tvclass']:
                subplot.append(e1['name'])
            plot.append(' '.join(subplot))
        if 'director' in e:
            subplot = []
            for e1 in e['director']:
                subplot.append(e1['name'])
            plot.append(u'导演: ' + ' '.join(subplot))
        if 'actor' in e:
            subplot = []
            for e1 in e['actor']:
                subplot.append(e1['name'])
            plot.append(u'演员: ' + ' '.join(subplot))
        if 'aboutme' in e:
            plot.append(e['aboutme'])
        plot = '\n'.join(plot)
        ret.append({'title': e['title'], 'url': urljoin(url, e['url']), 'img': urljoin(url, e['photo']), 'plot': plot})
    ret.append({'title': 'Next Page', 'category': cat, 'page': page + 1})
    return ret


def search(s):
    url = 'https://www.wekan.tv/index.php/search/list?content=%s&page=1&pagesize=20' % quote(s)
    try:
        data = getjson(url)
    except Exception as e:
        return {'code': 'huarentv 500', 'error': str(e)}
    ret = []
    for e in data['data']['list']:
        ret.append({'title': e['title'], 'url': urljoin(url, e['url']), 'img': urljoin(url, e['photo'])})
    return ret


def show(url):
    o = urlparse(url)
    p = o.path.split('/')
    url = 'http://www.wekan.tv/index.php/video/part?tvid=%s' % p[-1]
    try:
        data = getjson(url)
    except Exception as e:
        return {'code': 'huarentv 200', 'error': str(e)}
    ret = []
    if 'data' not in data:
        return {'code': 'huarentv 201'}
    if 'partList' not in data['data']:
        return {'code': 'huarentv 202'}
    for e in data['data']['partList']:
        ret.append({'title': e['part_title'], 'url': urljoin(url, e['url'])})
    return ret
